==================================
pyttsx - Text-to-speech x-platform
==================================

This documentation describes the pyttsx Python package v |release| and was rendered on |today|. 

.. rubric:: Table of Contents

.. toctree::
   :maxdepth: 2
   
   support
   engine
   drivers
   changelog

.. rubric:: Project Links

* `Project home page at Launchpad`__
* `Package listing in PyPI`__
* `Documentation in PyPI`__

__ https://launchpad.net/pyttsx
__ http://pypi.python.org/pypi/pyttsx
__ http://packages.python.org/pyttsx